@@ -16,7 +16,9 @@ extern "C" int _v_s_n_printf ( char *str, size_t n, const char *format, va_list
 #else
 #undef __STRICT_ANSI__ /* for __MINGW32__ */
 #define _BSD_SOURCE 1 /* vsnprintf(); may be emulated with fixup_vsnprintf() */
+#ifndef __APPLE__ /* SUXX: Max OS X has #ifndef _POSIX_SOURCE around lstat() :-( */
 #define _POSIX_SOURCE 1 /* also popen() */
+#endif
 #define _POSIX_C_SOURCE 2 /* also popen() */
 #define _XOPEN_SOURCE_EXTENDED 1 /* Digital UNIX lstat */
 #ifndef _XPG4_2
@@ -520,7 +522,8 @@ void Filter::PipeE::vi_write(char const*buf, slen_t len) {
     vi_check();
     p=(FILE*)NULLP;
     FILE *f=fopen(tmpname(),"rb");
-    if (NULLP==f) Error::sev(Error::EERROR) << "Filter::PipeE" <<": fopen() after pclose() failed: " << tmpname << (Error*)0;
+    if (NULLP==f) Error::sev(Error::EERROR) << "Filter::PipeE" <<": fopen() after pclose() failed: "
+      << redir_cmd << ": " << tmpname << (Error*)0;
     vi_copy(f);
     // if (ferror(f)) Error::sev(Error::EERROR) << "Filter::Pipe: fread() tmpfile failed" << (Error*)0;
     // fclose(f);
@@ -798,7 +801,9 @@ bool Files::tmpRemove=true;
 
 static int cleanup_remove(Error::Cleanup *cleanup) {
   if (Files::tmpRemove) return Files::removeIf(cleanup->getBuf());
+#if 0 /* Dat: produces nested errors */
   Error::sev(Error::WARNING) << "keeping tmp file: " << cleanup->getBuf() << (Error*)0;
+#endif
   return 0;
 }
 
@@ -810,7 +815,9 @@ static int cleanup_remove_cond(Error::Cleanup *cleanup) {
   if (*(FILE**)cleanup->data!=NULLP) {
     fclose(*(FILE**)cleanup->data);
     if (Files::tmpRemove) return Files::removeIf(cleanup->getBuf());
+#if 0 /* Dat: produces nested errors */
     Error::sev(Error::WARNING) << "keeping tmp2 file: " << cleanup->getBuf() << (Error*)0;
+#endif
   }
   return 0;
 }
