@@ -170,7 +170,8 @@ static const unsigned
   OPT_OutputFile=0xF2,
   OPT_Scale=0x101,
   OPT_Margins=0x112,
-  OPT_Transparent=0x122;
+  OPT_Transparent=0x122,
+  OPT_TmpRemove=0x132;
 
 /** @param s an option (lower/upper case intact), without leading `-'s
  * @param slen length of option 
@@ -206,6 +207,7 @@ static unsigned sam2p_optval(char const* s, slen_t slen) {
     /* printf("buf=(%s)\n", buf); */
     if (0==strcmp(buf, "sampleformat")) return OPT_SampleFormat;
     if (0==strcmp(buf, "loadhints")) return OPT_LoadHints;
+    if (0==strcmp(buf, "tmpremove")) return OPT_TmpRemove;
     if (0==strcmp(buf, "transparent")) return OPT_Transparent;
     if (0==strcmp(buf, "hints")) return OPT_Hints;
     if (0==strcmp(buf, "ps")
@@ -280,6 +282,7 @@ static bool one_liner(SimBuffer::B &jobss, char const *const* a) {
   SimBuffer::B Hints; /* MiniPS code */
   /* ^^^ Imp: separate hint for each -c arg?? */
   SimBuffer::B LoadHints;
+  bool TmpRemove_p=true;
   Rule::Cache::pr_t Predictor=Rule::Cache::PR_None; /* Imp: separate for each Compression */
   Rule::Cache::ff_t FileFormat=Rule::Cache::FF_default;
   Rule::Cache::te_t TransferEncoding=Rule::Cache::TE_default;
@@ -352,6 +355,7 @@ static bool one_liner(SimBuffer::B &jobss, char const *const* a) {
       /* Dat: now opt, paramlen and param are correct */
       switch (opt) {
        case OPT_LoadHints: LoadHints << ',' << param; break;
+       case OPT_TmpRemove: TmpRemove_p=GenBuffer::parseBool(param, paramlen); break;
        case OPT_Transparent: Transparent=param; break; /* Imp: is this good memory management */
        case OPT_Hints: Hints << '\n' << param; break;
        case OPT_PSL1: FileFormat=Rule::Cache::FF_PSL1; break;
@@ -363,6 +367,7 @@ static bool one_liner(SimBuffer::B &jobss, char const *const* a) {
              if (paramlen==0 || 0==GenBuffer::nocase_strcmp(param, "job"))  do_DisplayJobFile=true;
         else if (0==GenBuffer::nocase_strcmp(param, "warn")) buildProfile_quiet=false;
         else if (GenBuffer::nocase_strbegins(param, "warn:")) buildProfile_quiet=!GenBuffer::parseBool(param+5, paramlen-5);
+        else if (0==GenBuffer::nocase_strcmp(param, "quiet")) { buildProfile_quiet=true; Error::setTopPrinted(Error::ERROR_CONT); } /* Dat: hide warnings, info etc. */ /* at Fri Aug 26 07:54:00 CEST 2005 */
         else if (GenBuffer::nocase_strbegins(param, "job:")) do_DisplayJobFile=GenBuffer::parseBool(param+4, paramlen-4);
         else do_DisplayJobFile=GenBuffer::parseBool(param, paramlen); /* Imp: better error report */
         break;
@@ -811,6 +816,7 @@ static bool one_liner(SimBuffer::B &jobss, char const *const* a) {
   jobss.appendDumpPS(SimBuffer::Static(OutputFile), true);
   jobss << "\n/LoadHints ";
   jobss.appendDumpPS(LoadHints, true);
+  jobss << "\n/TmpRemove " << (TmpRemove_p ? "true" : "false");
   jobss << "\n/Profile[\n";
   
   unsigned coi, sfi;
@@ -1021,7 +1027,7 @@ void run_sam2p_engine(Files::FILEW &sout, Files::FILEW &serr, char const*const*a
   Rule::deleteProfile(rule_list);
   MiniPS::delete0(job); /* frees OutputFile etc. */
 
-  fputs("Success.\n", stderr);
+  if (Error::getTopPrinted()+0<=Error::NOTICE+0) fputs("Success.\n", stderr);
   fflush(stdout); fflush(stderr);
   Error::cexit(0);
 }
@@ -1041,6 +1047,8 @@ int main(int, char const*const* argv) {
   bool versionp=argv[0]!=(char const*)NULLP && argv[1]!=(char const*)NULLP && argv[2]==(char const*)NULLP && (
              option_eq(argv[1], "-version") || 
              option_eq(argv[1], "-v"));
+  bool quietp=argv[0]!=(char const*)NULLP && argv[1]!=(char const*)NULLP &&
+             option_eq(argv[1], "-j:quiet");
   init_sam2p_engine(argv[0]);
   
   if (versionp) {
@@ -1049,11 +1057,11 @@ int main(int, char const*const* argv) {
   }
 
   /* Don't print diagnostics to stdout, becuse it might be the OutputFile */
-  serr << "This is " << Error::banner0 << ".\n";
+  if (!quietp) { serr << "This is " << Error::banner0 << ".\n"; }
   init_loader();
-  serr << "Available Loaders:"; Image::printLoaders(serr); serr << ".\n";
+  if (!quietp) { serr << "Available Loaders:"; Image::printLoaders(serr); serr << ".\n"; }
   init_applier();
-  serr << "Available Appliers:"; Rule::printAppliers(serr); serr << ".\n";
+  if (!quietp) { serr << "Available Appliers:"; Rule::printAppliers(serr); serr << ".\n"; }
 
   run_sam2p_engine(sout, serr, argv+(argv[0]!=(char const*)NULLP), helpp);
   return 0; /*notreached*/
